.. module:: dyntrack
.. automodule:: dyntrack
   :noindex:


API
===

Import dyntrack as::

   import dyntrack as dt

Data loading and type
--------------------

.. autosummary::
    :toctree: .

    DynTrack
    ut.load_data

Analysis
--------

.. autosummary::
    :toctree: .

    tl.vector_field
    tl.FTLE
    tl.fit_ppt

Plotting
--------

.. autosummary::
    :toctree: .

    pl.tracks
    pl.vector_field
    pl.FTLE
    pl.fit_ppt
